import { Button, Space, Modal, FormInstance } from "antd";
import { inject, observer } from "mobx-react";
import type { ColumnsType } from "antd/es/table";
import BTable from "@/components/b_table";
import { useEffect, useState } from "react";
import { UserDataType } from "@/model/userModel";
import { Store } from "antd/lib/form/interface";
import SimpleForm from "@/components/form/simple_form";
import React from "react";
import { FormType } from "@/components/form/interface";
import baseHttp from "@/service/base";

const Emergency = (props: Store) => {
  const { emergencyStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [record, setRecord] = useState<any>(null);
  const [tagId, setId] = useState<Number | null>(null);
  const [userList, setUserList] = useState<Array<any>>([]);
  const columns: ColumnsType<UserDataType> = [
    { title: "应急处突名称", dataIndex: "emergency_name" },
    { title: "目标位置", dataIndex: "target_location" },
    { title: "目标精度", dataIndex: "long" },
    { title: "目标纬度", dataIndex: "lat" },
    { title: "任务描述", dataIndex: "desc" },
    {
      title: "完成状态",
      dataIndex: "status",
      render: (accomplish) =>
        accomplish.status === 0 ? (
          <span style={{ color: "green" }}>进行中</span>
        ) : (
          <span style={{ color: "red" }}>已完成</span>
        ),
    },
    {
      title: "操作",
      dataIndex: "id",
      render: (any, record) => (
        <Space wrap>
          <Button
            type="dashed"
            size="small"
            onClick={() => {
              edit(record);
            }}
          >
            编辑
          </Button>
          <Button
            type="dashed"
            size="small"
            onClick={() => {
              emergencyStore.deleteItem(record.id);
            }}
          >
            完成
          </Button>
          <Button
            type="dashed"
            danger
            size="small"
            onClick={() => {
              dele(record)
            }}
          >
            删除
          </Button>
        </Space>
      ),
    },
  ];
  const dele = (record)=>{
    emergencyStore.deleteItem(record.identity);
  }
  const edit = (record) => {
    setProjectConfig(defaultConfig);
   
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(record);
    setRecord(record);
    setId(record.id);
  };
  const onFinish = (values: any) => {
    let data = {
      ...values,
      long: values.marker["lng"],
      lat: values.marker["lat"],
    };
    if (!tagId) {
      emergencyStore.add(data);
    } else {
      emergencyStore.putItem(tagId, data);
    }
    setIsModalOpen(false);
  };
  useEffect(() => {
    emergencyStore.getlist();
    baseHttp.get("/user/list", null).then((res) => {
      let data = res.data?.record ?? [];
      data.forEach((item) => {
        item.label = item.account;
        item.value = item.identity;
      });
      setUserList(data ?? []);
    });
  }, [emergencyStore]);
  const defaultConfig = [
    {
      type: FormType.input,
      label: "处突名称",
      name: "emergency_name",
      value: "",
      rules: [{ required: true, message: "请输入处突名称!" }],
    },
    {
      type: FormType.input,
      label: "任务描述",
      name: "desc",
      value: "",
      rules: [{ required: true, message: "请输入任务描述!" }],
    },
    {
      type: FormType.input,
      label: "目标位置",
      name: "target_location",
      value: "",
      rules: [{ required: true, message: "请输入任务描述!" }],
    },
    {
      type: FormType.map,
      label: "坐标信息", 
      name: "marker",
      value: "",
      rules: [{ required: true, message: "请输入任务描述!" }],
    },
    {
      type: FormType.cehckboxGroup,
      label: "参与人员选择",
      name: "user_id",
      value: [],
      checkboxData: userList,
      rules: [{ required: true, message: "请选择参与人员!" }],
    },
  ];
  const onFinishFailed = () => {};
  // 用户选择回调
  return (
    <div className="contentBox">
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <Space direction="horizontal" size={"middle"}>
          <Button
            type="default"
            onClick={() => {
              setProjectConfig(defaultConfig);
              setId(null);
              setIsModalOpen(true);
            }}
          >
            任务发布
          </Button>
        </Space>

        <BTable
          store={emergencyStore}
          columns={columns}
          dataSource={emergencyStore.list}
        />
        <Modal
          title={!tagId ? "任务发布" : "任务编辑"}
          width={1200}
          open={isModalOpen}
          afterClose={() => formRef.current?.resetFields()}
          onOk={() => formRef.current?.submit()}
          onCancel={() => {
            setId(null);
            setIsModalOpen(false);
          }}
        >
          <SimpleForm
            formRef={formRef}
            createCallback={() => {
              formRef.current?.setFieldsValue(record);
            }}
            formName="card_basic"
            colProps={25}
            subBtnName="提交"
            formDatas={projectConfig}
            onFinish={onFinish}
            initialValues={true}
            onFinishFailed={onFinishFailed}
          />
        </Modal>
      </Space>
    </div>
  );
};

export default inject("emergencyStore")(observer(Emergency));
