import { Button, Space, Modal, FormInstance, Form, Select } from "antd";
import { inject, observer } from "mobx-react";
import type { ColumnsType } from "antd/es/table";
import BTable from "@/components/b_table";
import { useEffect, useState } from "react";
import { UserDataType } from "@/model/userModel";
import { Store } from "antd/lib/form/interface";
import SimpleForm from "@/components/form/simple_form";
import React from "react";
import { FormType } from "@/components/form/interface";
import baseHttp from "@/service/base";
import dayjs from "dayjs";
const { Option } = Select;

const Trainings = (props: Store) => {
  const { trainingStore, trainingCatStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [record, setRecord] = useState<any>(null);
  const [tagId, setId] = useState<Number | null>(null);
  const [stashList, setStash] = useState<any>(null); // 仓库列表
  const [userList, setUserList] = useState<Array<any>>([]);
  const columns: ColumnsType<UserDataType> = [
    { title: "任务标题", dataIndex: "title" },
    { title: "任务描述", dataIndex: "desc" },
    { title: "任务地点", dataIndex: "address" },
    { title: "任务开始时间", dataIndex: "start_time" },
    { title: "任务结束时间", dataIndex: "end_time" },
    { title: "任务积分设置", dataIndex: "score" },
    { title: "任务类别", dataIndex: "category_identity" },
    {
      title: "操作",
      dataIndex: "id",
      render: (any, record) => (
        <Space wrap>
          <Button
            type="dashed"
            size="small"
            onClick={() => {
              edit(record);
            }}
          >
            编辑
          </Button>
          <Button
            type="dashed"
            danger
            size="small"
            onClick={() => {
              dele(record);
            }}
          >
            删除
          </Button>
        </Space>
      ),
    },
  ];
  const dele = (record) => {
    trainingStore.deleteItem(record.identity);
  };
  const edit = (record) => {
    let data = {
      ...record,
      start_time: dayjs(record.start_time),
      end_time: dayjs(record.end_time),
    };
    setProjectConfig(defaultConfig);
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(data);
    setRecord(data);
    setId(record.id);
  };
  useEffect(() => {
    trainingCatStore.getlist().then(() => {
      setStash(trainingCatStore.list);
    });
    baseHttp.get("/user/list", null).then((res) => {
      let data = res.data?.record ?? [];
      data.forEach((item) => {
        item.label = item.account;
        item.value = item.identity;
      });
      setUserList(data ?? []);
    });
  }, [trainingCatStore]);

  const onFinish = (values: any) => {
    let data = {
      ...values,
      score: Number(values.score),
      count: Number(values.count),
    };
    if (!tagId) {
      trainingStore.add(data);
    } else {
      trainingStore.putItem(tagId, data);
    }
    setIsModalOpen(false);
  };
  useEffect(() => {
    trainingStore.getlist();
  }, [trainingStore]);
  const defaultConfig = [
    {
      type: FormType.input,
      label: "任务标题",
      name: "title",
      value: "",
      rules: [{ required: true, message: "请输入任务标题!" }],
    },
    {
      type: FormType.input,
      label: "任务描述",
      name: "desc",
      value: "",
      rules: [{ required: true, message: "请输入任务描述!" }],
    },
    {
      type: FormType.input,
      label: "任务地点",
      name: "address",
      value: "",
      rules: [{ required: true, message: "请输入任务地点!" }],
    },
    {
      type: FormType.date,
      label: "任务开始时间",
      name: "start_time",
      value: "",
      rules: [{ required: true, message: "请输入任务开始时间!" }],
    },
    {
      type: FormType.date,
      label: "任务结束时间",
      name: "end_time",
      value: "",
      rules: [{ required: true, message: "请输入任务结束时间!" }],
    },
    {
      type: FormType.input,
      label: "任务积分设置",
      name: "score",
      value: "",
      rules: [{ required: true, message: "请输入任务积分设置!" }],
    },
    {
      type: FormType.input,
      label: "训练次数",
      name: "count",
      value: 0,
      rules: [{ required: true, message: "请输入训练次数!" }],
    },
    {
      type: FormType.cehckboxGroup,
      label: "参与人员选择",
      name: "user_id",
      value: [],
      checkboxData: userList,
      rules: [{ required: true, message: "请选择参与人员!" }],
    },
  ];
  const onFinishFailed = () => {};
  // 用户选择回调
  return (
    <div className="contentBox">
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <Space direction="horizontal" size={"middle"}>
          <Button
            type="default"
            onClick={() => {
              setProjectConfig(defaultConfig);
              setId(null);
              setIsModalOpen(true);
            }}
          >
            任务发布
          </Button>
        </Space>

        <BTable
          store={trainingStore}
          columns={columns}
          dataSource={trainingStore.list}
        />
        <Modal
          title={!tagId ? "任务发布" : "任务编辑"}
          width={800}
          open={isModalOpen}
          afterClose={() => formRef.current?.resetFields()}
          onOk={() => formRef.current?.submit()}
          onCancel={() => {
            setId(null);
            setIsModalOpen(false);
          }}
        >
          <SimpleForm
            formRef={formRef}
            createCallback={() => {
              formRef.current?.setFieldsValue(record);
            }}
            formName="card_basic"
            colProps={25}
            subBtnName="提交"
            formDatas={projectConfig}
            onFinish={onFinish}
            initialValues={true}
            onFinishFailed={onFinishFailed}
          >
            <>
              <Form.Item
                key="category_identity"
                label="训练类别"
                name="category_identity"
                rules={[{ required: true, message: "请选择训练类别!" }]}
              >
                <Select placeholder="">
                  {stashList?.map((v: any) => {
                    return (
                      <Option key={v.identity} value={v.identity}>
                        {v.name}
                      </Option>
                    );
                  })}
                </Select>
              </Form.Item>
            </>
          </SimpleForm>
        </Modal>
      </Space>
    </div>
  );
};

export default inject("trainingStore", "trainingCatStore")(observer(Trainings));
